pub struct PyAgent {
pub agent: Arc<Agent>,
}Fields
agent: Arc<Agent>Implementations
Sourceimpl PyAgent
impl PyAgent
Sourcepub fn new(
provider: &Bound<'_, PyAny>,
system_instruction: Option<&Bound<'_, PyAny>>,
) -> Result<Self, AgentError>
pub fn new( provider: &Bound<'_, PyAny>, system_instruction: Option<&Bound<'_, PyAny>>, ) -> Result<Self, AgentError>
Creates a new Agent instance.
Arguments:
provider- A Python object representing the provider, expected to be an a variant of Provider or a string that can be mapped to a provider variant
pub fn execute_task( &self, task: &mut Task, output_type: Option<Bound<'_, PyAny>>, ) -> Result<PyAgentResponse, AgentError>
Sourcepub fn execute_prompt(
&self,
prompt: &mut Prompt,
output_type: Option<Bound<'_, PyAny>>,
) -> Result<PyAgentResponse, AgentError>
pub fn execute_prompt( &self, prompt: &mut Prompt, output_type: Option<Bound<'_, PyAny>>, ) -> Result<PyAgentResponse, AgentError>
Executes a prompt directly without a task.
Arguments:
prompt- The prompt to execute.output_type- An optional Python type to bind the response to. If provide, it is expected that the output type_object matches the response schema defined in the prompt.
Returns:
PyAgentResponse- The response from the agent.
pub fn system_instruction<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyList>, AgentError>
pub fn id(&self) -> &str