pub struct PyAgentResponse {
pub response: AgentResponse,
pub output_type: Option<Py<PyAny>>,
pub failed_conversion: bool,
}Fields
response: AgentResponseoutput_type: Option<Py<PyAny>>failed_conversion: boolImplementations
Sourceimpl PyAgentResponse
impl PyAgentResponse
pub fn id(&self) -> &str
pub fn token_usage(&self) -> Result<Usage, AgentError>
pub fn log_probs(&self) -> LogProbs
Sourcepub fn result<'py>(
&mut self,
py: Python<'py>,
) -> Result<Bound<'py, PyAny>, AgentError>
pub fn result<'py>( &mut self, py: Python<'py>, ) -> Result<Bound<'py, PyAny>, AgentError>
This will map a the content of the response to a python object. A python object in this case will be either a passed pydantic model or support potatohead types. If neither is porvided, an attempt is made to parse the serde Value into an appropriate Python type. Types:
- Serde Null -> Python None
- Serde Bool -> Python bool
- Serde String -> Python str
- Serde Number -> Python int or float
- Serde Array -> Python list (with each item converted to Python type)
- Serde Object -> Python dict (with each key-value pair converted to Python type)